Documentation
¶
Overview ¶
Package config provides a content type to manage the Ponzu system's configuration settings for things such as its name, domain, HTTP(s) port, email, server defaults and backups.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
item.Item
Name string `json:"name"`
Domain string `json:"domain"`
BindAddress string `json:"bind_addr"`
HTTPPort string `json:"http_port"`
HTTPSPort string `json:"https_port"`
AdminEmail string `json:"admin_email"`
ClientSecret string `json:"client_secret"`
Etag string `json:"etag"`
DisableCORS bool `json:"cors_disabled"`
DisableGZIP bool `json:"gzip_disabled"`
DisableHTTPCache bool `json:"cache_disabled"`
CacheMaxAge int64 `json:"cache_max_age"`
CacheInvalidate []string `json:"cache"`
BackupBasicAuthUser string `json:"backup_basic_auth_user"`
BackupBasicAuthPassword string `json:"backup_basic_auth_password"`
}
Config represents the confirgurable options of the system
func (*Config) MarshalEditor ¶
MarshalEditor writes a buffer of html to edit a Post and partially implements editor.Editable
Click to show internal directories.
Click to hide internal directories.